aiodocker: AsyncIO bindings for docker.io — aiodocker 0.8.0-a0 documentation

# aiodocker: AsyncIO bindings for docker.io

A simple Docker HTTP API wrapper written with asyncio and aiohttp.

## Installation

    pip install aiodocker

## Examples

    import asyncio
    import aiodocker

    async def list_things():
        docker = aiodocker.Docker()
        print('== Images ==')
        for image in (await docker.images.list()):
            tags = image['RepoTags'][0] if image['RepoTags'] else ''
            print(image['Id'], tags)
        print('== Containers ==')
        for container in (await docker.containers.list()):
            print(f" {container._id}")
        await docker.close()

    async def run_container():
        docker = aiodocker.Docker()
        print('== Running a hello-world container ==')
        container = await docker.containers.create_or_replace(
            config={
                'Cmd': ['/bin/ash', '-c', 'echo "hello world"'],
                'Image': 'alpine:latest',
            },
            name='testing',
        )
        await container.start()
        logs = await container.log(stdout=True)
        print(''.join(logs))
        await container.delete(force=True)
        await docker.close()

    if __name__ == '__main__':
        loop = asyncio.get_event_loop()
        loop.run_until_complete(list_things())
        loop.run_until_complete(run_container())
        loop.close()

### Source code

The project is hosted on GitHub: https://github.com/aio-libs/aiodocker

Please feel free to file an issue on the bug tracker if you have found a bug or have some suggestion in order to improve the library.

### Communication channels

aio-libs google group: https://groups.google.com/forum/#!forum/aio-libs

Feel free to post your questions and ideas here.

Gitter Chat https://gitter.im/aio-libs/Lobby

We support Stack Overflow. Please add python-asyncio tag to your question there.

### Author and License

The `aiodocker` package is written by Andrew Svetlov.

It’s Apache 2 licensed and freely available.

## Indices and tables

- Index
- Module Index
- Search Page